# BD103 Python Package

These are some utility modules and fun stuff that might make a good dependency. There are some subpackages that has special purposes.

- `bd103.ext`: Contains extensions and plugins to other Python packages
- `bd103.shared`: Contains modules that are shared between different implementations of BD103's library
- `bd103.data`: Contains data types for various formats

## Installation

```shell
python -m pip install -U bd103
```

## Getting Started

A good idea is too look through the [documentation](https://bd103.github.io/BD103-Python/) to find modules that might pique your interest. A recommended one is the [decorators](https://bd103.github.io/BD103-Python/api/decorators.html) module.

## Contributing

Feel free to submit a PR if you want to contribute to the package. For more information, see [CONTRIBUTING.md](CONTRIBUTING.md).
